@@ -13,8 +13,17 @@ function test_bluer_ugv_help() {
         "@swallow dataset list" \
         "@swallow dataset upload" \
         \
+        "@swallow env" \
+        "@swallow env cp" \
+        "@swallow env list" \
+        \
+        "@swallow select_target" \
+        \
         "@ugv" \
         \
+        "@ugv parts" \
+        "@ugv parts adjust" \
+        \
         "@ugv pypi" \
         "@ugv pypi browse" \
         "@ugv pypi build" \
