@@ -1,6 +1,6 @@
 #! /usr/bin/env bash
 
-function test_bluer_ugv_swallow_download_upload() {
+function test_bluer_ugv_swallow_dataset_download_upload() {
     local options=$1
 
     bluer_ugv_swallow_dataset_download
