@@ -8,7 +8,7 @@ load_config(__name__)
 BLUER_BEAST_MODEL = get_env("BLUER_BEAST_MODEL")
 
 BLUER_UGV_CAMERA_TRAINING_PERIOD = get_env("BLUER_UGV_CAMERA_TRAINING_PERIOD", 3.0)
-BLUER_UGV_CAMERA_PREDICTION_PERIOD = get_env("BLUER_UGV_CAMERA_PREDICTION_PERIOD", 1.5)
+BLUER_UGV_CAMERA_ACTION_PERIOD = get_env("BLUER_UGV_CAMERA_ACTION_PERIOD", 1.5)
 
 BLUER_UGV_SWALLOW_STEERING_SETPOINT = get_env("BLUER_UGV_SWALLOW_STEERING_SETPOINT", 50)
 
