@@ -7,9 +7,18 @@ def help_combine(
     tokens: List[str],
     mono: bool,
 ) -> str:
-    options = xtra("count=<count>,~download,~recent,~split,upload", mono=mono)
+    options = "".join(
+        [
+            "count=<count>",
+            xtra(",~download,~recent,", mono=mono),
+            "sequence=<3>",
+            xtra(",~split,", mono=mono),
+            "upload",
+        ]
+    )
 
     args = [
+        "[--datasets <object-name-1>+<object-name-2>]",
         "[--test_ratio 0.1]",
         "[--train_ratio 0.8]",
     ]
@@ -64,6 +73,24 @@ def help_edit(
     )
 
 
+def help_list(
+    tokens: List[str],
+    mono: bool,
+) -> str:
+    options = xtra("~download", mono=mono)
+
+    return show_usage(
+        [
+            "@swallow",
+            "dataset",
+            "list",
+            f"[{options}]",
+        ],
+        "list the swallow dataset.",
+        mono=mono,
+    )
+
+
 def help_upload(
     tokens: List[str],
     mono: bool,
@@ -86,5 +113,6 @@ help_functions = {
     "combine": help_combine,
     "download": help_download,
     "edit": help_edit,
+    "list": help_list,
     "upload": help_upload,
 }
